@@ -1,5 +1,6 @@
 from flask import request, url_for, redirect
 import flask
+from flask.ext.debugtoolbar import DebugToolbarExtension
 
 
 def current_for(**values):
@@ -29,3 +30,14 @@ class Glask(flask.Flask):
                                     instance_path, instance_relative_config)
         self.jinja_env.globals.update(current_for=current_for)
         self.request_class = Request
+        _config_from_object = self.config.from_object
+
+        def config_from_object(object):
+            _config_from_object(object)
+            self.init_after_config()
+
+        self.config.from_object = config_from_object
+
+    def init_after_config(self):
+        if self.debug:
+            DebugToolbarExtension(self)
